========================
Django Frontend Static
========================

A basic Django application to install often used static files.

With the convenience of an installable Django application, easily add some of the most widely used static files.

There are no templates included. If you want a skeleton application built on HTML5 Boilerplate and Twitter Bootstrap then checkout `django-frontend-skeleton <https://github.com/jonfaustman/django-frontend-skeleton>`_. If you want a light-weight template built on HTML5 Boilerplate without any static files then check out `django-frontend-template <https://github.com/jonfaustman/django-frontend-template>`_.

-------------
Sunsetting
-------------

Django Frontend Static is sunsetting. After two more release cycles it will ofically be discontinued. Please transition to `django-frontend <https://github.com/jonfaustman/django-frontend>`_.

While continuing to use Django Frontend Static, be sure to force upgrade to avoid namespacing problems.

`Read this article <http://jonfaustman.com/2013/08/07/django-frontend/>`_ for more information.

---------
Starring
---------
* `HTML5 Boilerplate (based on 4.2.0) <https://github.com/h5bp/html5-boilerplate>`_
* `Modernizr (2.6.2) <https://github.com/Modernizr/Modernizr>`_
* `jQuery (1.10.2) and (2.0.3) <https://github.com/jquery/jquery>`_
* `jQuery UI (1.10.3) <https://github.com/jquery/jquery-ui>`_
* `jQuery DataTables (1.9.4) <https://github.com/DataTables/DataTables>`_
* `jQuery Dynamic Formset (1.2) <https://code.google.com/p/django-dynamic-formset>`_
* `jQuery Smooth Scroll (1.4.11) <https://github.com/kswedberg/jquery-smooth-scroll>`_
* `Twitter Bootstrap (3.0.0 RC1) <https://github.com/twbs/bootstrap>`_
* `iOS-Orientationchange-Fix <https://github.com/scottjehl/iOS-Orientationchange-Fix>`_
* `famfamfam's Silk Icons <http://www.famfamfam.com/lab/icons/silk/>`_

-----------------
More Information
-----------------

For more information, instructions on how to get started, a changelog and a roadmap `read the documentation <https://django-frontend-static.readthedocs.org/>`_.